package cn.com.ty.lift.business.project.controller;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.maintenance.dao.entity.model.request.MaintenanceAppRequest;
import cn.com.ty.lift.business.maintenance.dao.entity.model.request.MaintenanceRecordRequest;
import cn.com.ty.lift.business.maintenance.dao.entity.model.response.MaintenancePlanResponse;
import cn.com.ty.lift.business.maintenance.dao.entity.model.response.MaintenanceRecordResponse;
import cn.com.ty.lift.business.project.dao.entity.model.request.CompanyRequest;
import cn.com.ty.lift.business.project.dao.entity.model.request.ProjectDetailRequest;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectCompanyResponse;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectDetailResponse;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectLiftResponse;
import cn.com.ty.lift.business.project.service.ProjectAppService;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * @author bieao
 * @date 2019/12/31
 * @description app端项目管理控制层
 */
@RestController
@RequestMapping("app")
public class ProjectAppController {

    @Resource
    private ProjectAppService projectAppService;

    /**
     * @param request 公司id
     * @return RestResponse 项目列表
     * @description 根据公司id查询公司下项目列表
     * @date 2019/12/31 3:13 PM
     */
    @PostMapping("project/list")
    public RestResponse list(@Valid @RequestBody CompanyRequest request) {
        IPage<ProjectCompanyResponse> page = projectAppService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目id
     * @return RestResponse 电梯列表
     * @description 根据项目id查询项目下电梯列表
     * @date 2019/12/31 3:13 PM
     */
    @PostMapping("lift/list")
    public RestResponse list(@Valid @RequestBody ProjectDetailRequest request) {
        IPage<ProjectLiftResponse> page = projectAppService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 项目id
     * @return RestResponse 项目详情
     * @description 根据项目id查询项目详情
     * @date 2020/1/2 1:50 下午
     */
    @PostMapping("project/detail")
    public RestResponse detail(@Valid @RequestBody ProjectDetailRequest request) {
        ProjectDetailResponse response = projectAppService.detail(request);
        if (ObjectUtil.isEmpty(response)) {
            return RestResponse.success();
        }
        return RestResponse.success(response, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 用户id和维保状态
     * @return RestResponse 保养任务列表
     * @description 根据用户id和维保状态查询保养任务列表
     * @date 2020/1/6 11:29 上午
     */
    @PostMapping("maintenance/task")
    public RestResponse taskList(@Valid @RequestBody MaintenanceAppRequest request) {
        IPage<MaintenancePlanResponse> response = projectAppService.taskList(request);
        if (CollUtil.isEmpty(response.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(response, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 公司id和电梯id
     * @return RestResponse 保养信息
     * @description 根据公司id和电梯id查询上次保养信息
     * @date 2020/1/6 5:37 下午
     */
    @PostMapping("maintenance/record/info")
    public RestResponse recordInfo(@Valid @RequestBody MaintenanceRecordRequest request) {
        MaintenanceRecordResponse response = projectAppService.recordInfo(request);
        if (ObjectUtil.isEmpty(response)) {
            return RestResponse.success();
        }
        return RestResponse.success(response, MessageUtils.get("msg.query.detail.success"));
    }
}
